==> evolutility-server-node-1.1.0.tgz: package/models/data/music/track-data.js <==
module.exports = [
    {
        name: "Jap Man Sat Nam",
        length: "11:08",
        album: 1,
        genre: 7,   
    },
    {
        name: "Ek Ong Kaar",
        length: "8:42",
        album: 1,
        genre: 7,   
    },
    {
        name: "Servant of Peace",
        length: "7:12",
        album: 1,
        genre: 7,   
    },
    {
        name: "By Thy Grace",
        length: "7:45",
        album: 1,
        genre: 7,   
    },
    {
        name: "Gobinda Gobinda Hari Hari",
        length: "10:47",
        album: 1,
        genre: 7,   
    },
    {
        name: "Ong Namo",
        length: "10:01",
        album: 1,
        genre: 7,   
    },
    {
        name: "Ra Ma Da Sa",
        length: "13:32",
        album: 1,
        genre: 7,   
    },
    {
        name: "Long Time Sun",
        length: "3:58",
        album: 1,
        genre: 7,   
    },



    {
        name: "Amul - Priceless",
        length: "7:04",
        album: 2,
        genre: 7,
    },
    {
        name: "Gopaal",
        length: "8:04",
        album: 2,
        genre: 7,
    },
    {
        name: "Water of Your Love",
        length: "4:58",
        album: 2,
        genre: 7,
    },
    {
        name: "Har Uplift",
        length: "8:32",
        album: 2,
        genre: 7,
    },
    {
        name: "Darashan Maago",
        length: "12:55",
        album: 2,
        genre: 7,
    },
    {
        name: "Pooran Jot - Pure Light",
        length: "9:10",
        album: 2,
        genre: 7,
    },
    {
        name: "Har Har Har Har Gobinday",
        length: "12:03",
        album: 2,
        genre: 7,
    },
    {
        name: "Sat Naaraa-In",
        length: "8:32",
        album: 2,
        genre: 7,
    },



    {
        name: "You Are My Breath",
        length: "7:39",
        album: 3,
        genre: 7,
    },
    {
        name: "The Aramaic Lord's Prayer",
        length: "10:09",
        album: 3,
        genre: 7,
    },
    {
        name: "Dona Nobis Pacem",
        length: "8:23",
        album: 3,
        genre: 7,
    },
    {
        name: "Opening to Love",
        length: "8:43",
        album: 3,
        genre: 7,
    },
    {
        name: "Only You in My Heart",
        length: "9:28",
        album: 3,
        genre: 7,
    },
    {
        name: "Deep Peace",
        length: "8:55",
        album: 3,
        genre: 7,
    },
    {
        name: "Alleluia - Wahe Guru",
        length: "7:06",
        album: 3,
        genre: 7,
    },



    {
        name: "By Your Side",
        length: "4:34",
        album: 4,
    }, 
    {
        name: "Flow",
        length: "4:34",
        album: 4,
    }, 
    {
        name: "King of Sorrow",
        length: "4:52",
        album: 4,
    }, 
    {
        name: "Somebody Already Broke My Heart",
        length: "5:01",
        album: 4,
    }, 
    {
        name: "All About Our Love",
        length: "2:40",
        album: 4,
    }, 
    {
        name: "Slave Song",
        length: "4:12",
        album: 4,
    }, 
    {
        name: "The Sweetest Gift",
        length: "2:18",
        album: 4,
    }, 
    {
        name: "Every Word",
        length: "4:04",
        album: 4,
    }, 
    {
        name: "Immigrant",
        length: "3:48",
        album: 4,
    }, 
    {
        name: "Lovers Rock",
        length: "4:13",
        album: 4,
    }, 
    {
        name: "It's Only Love That Gets You Through",
        length: "3:53",
        album: 4,
    }, 




    {    
        name: "Honey",
        album: 5,
        genre: 4,
    },
    {    
        name: "Find My Baby",
        album: 5,
        genre: 4,
    },
    {    
        name: "Porcelain",
        album: 5,
        genre: 4,
    },
    {    
        name: "Why Does My Heart Feel So Bad?",
        album: 5,
        genre: 4,
    },
    {    
        name: "South Side",
        album: 5,
        genre: 4,
    },
    {    
        name: "Rushing",
        album: 5,
        genre: 4,
    },
    {    
        name: "Bodyrock",
        album: 5,
        genre: 4,
    },
    {    
        name: "Natural Blues",
        album: 5,
        genre: 4,
    },
    {    
        name: "Machete",
        album: 5,
        genre: 4,
    },
    {    
        name: "7",
        album: 5,
        genre: 4,
    },
    {    
        name: "Run On",
        album: 5,
        genre: 4,
    },
    {    
        name: "Down Slow",
        album: 5,
        genre: 4,
    },
    {    
        name: "If Things Were Perfect",
        album: 5,
        genre: 4,
    },
    {    
        name: "Everloving",
        album: 5,
        genre: 4,
    },
    {    
        name: "Inside",
        album: 5,
        genre: 4,
    },
    {    
        name: "Guitar, Flute & String",
        album: 5,
    },
    {    
        name: "The Sky Is Broken",
        album: 5,
        genre: 4,
    },
    {    
        name: "My Weakness",
        album: 5,
        genre: 4,
    }, 



    {    
        name: "We Are All Made of Stars",
        album: 6,
    },
    {    
        name: "In This World",
        album: 6,
    },
    {    
        name: "In My Heart",
        album: 6,
    },
    {    
        name: "Great Esacpe",
        album: 6,
    },
    {    
        name: "Signs of Love",
        album: 6,
    },
    {    
        name: "One of These Mornings",
        album: 6,
    },
    {    
        name: "Another Woman",
        album: 6,
    },
    {    
        name: "Fireworks",
        album: 6,
    },
    {    
        name: "Extreme Ways",
        album: 6,
    },
    {    
        name: "Jam for the Ladies",
        album: 6,
    },
    {    
        name: "Sunday (The Day Before My Birthday)",
        album: 6,
    },
    {    
        name: "18",
        album: 6,
    },
    {    
        name: "Sleep Alone",
        album: 6,
    },
    {    
        name: "At Least We Tried",
        album: 6,
    },
    {    
        name: "Harbour",
        album: 6,
    },
    {    
        name: "Look Back In",
        album: 6,
    },
    {    
        name: "The Rafters",
        album: 6,
    },
    {    
        name: "I'm Not Worried at All",
        album: 6,
    },



    {
        name: "Varanasi",
        length: "4:08",
        album: 7,
        genre: 4,
    },
    {
        name: "Aigiri Nam",
        length: "5:42",
        album: 7,
        genre: 4,
    },
    {
        name: "Sarvesham",
        length: "5:24",
        album: 7,
        genre: 4,
    },
    {
        name: "Mantra",
        length: "5:53",
        album: 7,
        genre: 4,
    },
    {
        name: "Dakshina",
        length: "6:48",
        album: 7,
        genre: 4,
    },
    {
        name: "Gothenburg",
        length: "6:58",
        album: 7,
        genre: 4,
    },
    {
        name: "Diosas",
        length: "4:21",
        album: 7,
        genre: 4,
    },
    {
        name: "Mangalam",
        length: "4:30",
        album: 7,
        genre: 4,
    },
    {
        name: "Calling Aslak",
        length: "4:36",
        album: 7,
        genre: 4,
    },
    {
        name: "Ganesha",
        length: "4:01",
        album: 7,
        genre: 4,
    },


]

==> evolutility-server-node-1.1.2.tgz: package/models/data/music/track-data.js <==
module.exports = [
    {
        name: "Jap Man Sat Nam",
        length: "11:08",
        album: 1,
        genre: 7,   
    },
    {
        name: "Ek Ong Kaar",
        length: "8:42",
        album: 1,
        genre: 7,   
    },
    {
        name: "Servant of Peace",
        length: "7:12",
        album: 1,
        genre: 7,   
    },
    {
        name: "By Thy Grace",
        length: "7:45",
        album: 1,
        genre: 7,   
    },
    {
        name: "Gobinda Gobinda Hari Hari",
        length: "10:47",
        album: 1,
        genre: 7,   
    },
    {
        name: "Ong Namo",
        length: "10:01",
        album: 1,
        genre: 7,   
    },
    {
        name: "Ra Ma Da Sa",
        length: "13:32",
        album: 1,
        genre: 7,   
    },
    {
        name: "Long Time Sun",
        length: "3:58",
        album: 1,
        genre: 7,   
    },



    {
        name: "Amul - Priceless",
        length: "7:04",
        album: 2,
        genre: 7,
    },
    {
        name: "Gopaal",
        length: "8:04",
        album: 2,
        genre: 7,
    },
    {
        name: "Water of Your Love",
        length: "4:58",
        album: 2,
        genre: 7,
    },
    {
        name: "Har Uplift",
        length: "8:32",
        album: 2,
        genre: 7,
    },
    {
        name: "Darashan Maago",
        length: "12:55",
        album: 2,
        genre: 7,
    },
    {
        name: "Pooran Jot - Pure Light",
        length: "9:10",
        album: 2,
        genre: 7,
    },
    {
        name: "Har Har Har Har Gobinday",
        length: "12:03",
        album: 2,
        genre: 7,
    },
    {
        name: "Sat Naaraa-In",
        length: "8:32",
        album: 2,
        genre: 7,
    },



    {
        name: "You Are My Breath",
        length: "7:39",
        album: 3,
        genre: 7,
    },
    {
        name: "The Aramaic Lord's Prayer",
        length: "10:09",
        album: 3,
        genre: 7,
    },
    {
        name: "Dona Nobis Pacem",
        length: "8:23",
        album: 3,
        genre: 7,
    },
    {
        name: "Opening to Love",
        length: "8:43",
        album: 3,
        genre: 7,
    },
    {
        name: "Only You in My Heart",
        length: "9:28",
        album: 3,
        genre: 7,
    },
    {
        name: "Deep Peace",
        length: "8:55",
        album: 3,
        genre: 7,
    },
    {
        name: "Alleluia - Wahe Guru",
        length: "7:06",
        album: 3,
        genre: 7,
    },



    {
        name: "By Your Side",
        length: "4:34",
        album: 4,
        genre: 9,
    }, 
    {
        name: "Flow",
        length: "4:34",
        album: 4,
        genre: 9,
    }, 
    {
        name: "King of Sorrow",
        length: "4:52",
        album: 4,
        genre: 9,
    }, 
    {
        name: "Somebody Already Broke My Heart",
        length: "5:01",
        album: 4,
        genre: 9,
    }, 
    {
        name: "All About Our Love",
        length: "2:40",
        album: 4,
        genre: 9,
    }, 
    {
        name: "Slave Song",
        length: "4:12",
        album: 4,
        genre: 9,
    }, 
    {
        name: "The Sweetest Gift",
        length: "2:18",
        album: 4,
        genre: 9,
    }, 
    {
        name: "Every Word",
        length: "4:04",
        album: 4,
        genre: 9,
    }, 
    {
        name: "Immigrant",
        length: "3:48",
        album: 4,
        genre: 9,
        description: "Adu - Janusz Podrazik",
    }, 
    {
        name: "Lovers Rock",
        length: "4:13",
        album: 4,
        genre: 9,
    }, 
    {
        name: "It's Only Love That Gets You Through",
        length: "3:53",
        album: 4,
        genre: 9,
        description: "Adu - Podrazik",
    }, 


    {    
        name: "Honey",
        length: "3:27",
        album: 5,
        genre: 4,
        description: "Moby, Bessie Jones, Alan Lomax",
    },
    {    
        name: "Find My Baby",
        length: "3:58",
        album: 5,
        genre: 4,
        description: "Moby, Willie Jones, Lomax",
    },
    {    
        name: "Porcelain",
        length: "4:01",
        album: 5,
        genre: 4,
    },
    {    
        name: "Why Does My Heart Feel So Bad?",
        length: "4:23",
        album: 5,
        genre: 4,
    },
    {    
        name: "South Side",
        length: "3:48",
        album: 5,
        genre: 4,
    },
    {    
        name: "Rushing",
        length: "2:58",
        album: 5,
        genre: 4,
    },
    {    
        name: "Bodyrock",
        length: "3:34",
        album: 5,
        genre: 4,
        description: "Moby, Gabriel Jackson, Bobby Robinson",
    },
    {    
        name: "Natural Blues",
        length: "4:12",
        album: 5,
        genre: 4,
        description: "Moby, Vera Hall, Lomax",
    },
    {    
        name: "Machete",
        length: "3:36",
        album: 5,
        genre: 4,
    },
    {    
        name: "7",
        album: 5,
        genre: 4,
    },
    {    
        name: "Run On",
        album: 5,
        genre: 4,
    },
    {    
        name: "Down Slow",
        album: 5,
        genre: 4,
    },
    {    
        name: "If Things Were Perfect",
        album: 5,
        genre: 4,
    },
    {    
        name: "Everloving",
        album: 5,
        genre: 4,
    },
    {    
        name: "Inside",
        album: 5,
        genre: 4,
    },
    {    
        name: "Guitar, Flute & String",
        album: 5,
    },
    {    
        name: "The Sky Is Broken",
        album: 5,
        genre: 4,
    },
    {    
        name: "My Weakness",
        album: 5,
        genre: 4,
    }, 



    {    
        name: "We Are All Made of Stars",
        album: 6,
        length: "4:32",
        genre: 4,
    },
    {    
        name: "In This World",
        album: 6,
        length: "4:02",
        genre: 4,
    },
    {    
        name: "In My Heart",
        album: 6,
        genre: 4,
        length: "4:36",
    },
    {    
        name: "Great Escape",
        album: 6,
        genre: 4,
        length: "2:09",
        description: "Moby, Maria Taylor, Orenda Fink",
    },
    {    
        name: "Signs of Love",
        album: 6,
        genre: 4,
        length: "4:25",
    },
    {    
        name: "One of These Mornings",
        album: 6,
        genre: 4,
        length: "3:12",
    },
    {    
        name: "Another Woman",
        album: 6,
        genre: 4,
        length: "3:56",
    },
    {    
        name: "Fireworks",
        album: 6,
        genre: 4,
        length: "2:13",
    },
    {    
        name: "Extreme Ways",
        album: 6,
        genre: 4,
        length: "3:57",
    },
    {    
        name: "Jam for the Ladies",
        album: 6,
        genre: 4,
        length: "3:22",
    },
    {    
        name: "Sunday (The Day Before My Birthday)",
        album: 6,
        genre: 4,
        length: "5:09",
    },
    {    
        name: "18",
        album: 6,
        genre: 4,
        length: "4:28"
    },
    {    
        name: "Sleep Alone",
        album: 6,
        genre: 4,
        length: "4:45",
    },
    {    
        name: "At Least We Tried",
        album: 6,
        genre: 4,
        length: "4:08",
    },
    {    
        name: "Harbour",
        album: 6,
        genre: 4,
        length: "6:27",
    },
    {    
        name: "Look Back In",
        album: 6,
        genre: 4,
        length: "2:20",
    },
    {    
        name: "The Rafters",
        album: 6,
        genre: 4,
        length: "3:22",
    },
    {    
        name: "I'm Not Worried at All",
        album: 6,
        genre: 4,
        length: "4:11",
    },



    {
        name: "Varanasi",
        length: "4:08",
        album: 7,
        genre: 4,
    },
    {
        name: "Aigiri Nam",
        length: "5:42",
        album: 7,
        genre: 4,
    },
    {
        name: "Sarvesham",
        length: "5:24",
        album: 7,
        genre: 4,
    },
    {
        name: "Mantra",
        length: "5:53",
        album: 7,
        genre: 4,
    },
    {
        name: "Dakshina",
        length: "6:48",
        album: 7,
        genre: 4,
    },
    {
        name: "Gothenburg",
        length: "6:58",
        album: 7,
        genre: 4,
    },
    {
        name: "Diosas",
        length: "4:21",
        album: 7,
        genre: 4,
    },
    {
        name: "Mangalam",
        length: "4:30",
        album: 7,
        genre: 4,
    },
    {
        name: "Calling Aslak",
        length: "4:36",
        album: 7,
        genre: 4,
    },
    {
        name: "Ganesha",
        length: "4:01",
        album: 7,
        genre: 4,
    },


]
